# Provisioner - Procure Hardware

The provisioner is responsible for:

* Procuring equipment

* Setting up the [Facility]()

* Maintaining stock of supplies in the [Facility]()

* Minimizing hardware supply chain security risks

## Directives

* MUST maintain chain of custody for all hardware until after it's properly stored or where necessary tamper-proofed

The different procedures are ordered in chronological preference, to improve the efficiency of setting up the system.

## Facility

1. Identify a location which is suitable for Level 2 ceremonies:

    * SHOULD be lockable to prevent inflow and outflow of persons during ceremonies

1. Procure an enclosure for locking equipment. A simple lockbox or a safe can be used. It should be at least large enough to fit several laptops, with some extra room.

1. Designate the location as the facility for conducting ceremonies and update documentation and policies to reflect this

## Preparing SD Cards

SD cards don't require special chain of custody, but ideally should be purchased from a reputable supplier.

### SD Card Models

{{ #include ../../../../hardware-models.md:sd-models }}

### Notes

* The location should always be well stocked with freshly formatted SD cards

    * There should be at least 20 microSD and 20 SD cards available for use

    * Both microSD and regular SD cards should be available

    * They should be formatted to `ext4` format

* Usage of these SD cards:

    * Transferring transaction data from online to air-gapped machine

    * Storing tamper proofing evidence produced at the end of the ceremony

### Procedure: formatting SD Card to `ext4`

{{ #include ../../../../sd-formatting.md:steps }}

## Tamper Proofing Equipment

### Vacuum Sealer and roll
{{ #include ../../../../tamper-evidence-methods.md:vsbwf-equipment}}

### Colored beads

{{ #include ../../../../tamper-evidence-methods.md:vsbwf-filler}}

### Digital camera
{{ #include ../../../../tamper-evidence-methods.md:digital-cameras}}

### Polaroid camera
{{ #include ../../../../tamper-evidence-methods.md:polaroid-cameras}}

## AirgapOS

An SD card with AirgapOS written to it will be required to run ceremonies.

{{ #include ../../../../one-time-use-airgapos.md:steps }}

## Computer Procurement

For [Level 2](../../../../threat-model.md#level-2) security, air-gapped computers which are used for cryptographic material management and operations are required.

### Models

{{ #include ../../../../hardware-models.md:computer-models }}

### Procedure

1. Follow the [chain of custody procurement procedure](../../../../hardware-procurement-and-chain-of-custody.md)

1. Apply [vaccum sealing with filler](../../../../tamper-evidence-methods.md#vacuum-sealed-bags-with-filler) tamper proofing.


### Shardfile 

There should be multiple SD cards containing the shardfile data. Shardfile data is produced during a [Root Entropy](todo) derivation ceremony.

* Label: "Shardfile"

* This should be write-locked and stored in tamper proofing along with air-gapped machine

## Trusted Keys

### Procedure

This procedure requires 2 individuals in order to witness the process.

1. Get a freshly formatted SD card 

1. Plug it into a computer

1. Navigate the the official Keychain repository of your organization

1. Select provisioner and approver keys from the Keychain repository

1. Export the keys using `gpg --armor --export <key_id> > <key_id:individual_name>.asc`

    * Repeat step for all needed keys

1. Copy the `.asc` files to the SD card

1. Use the `sdtool` to lock the card

{{ #include ../../../../sdtool-instructions.md:steps }}

1. Label the card "Trusted Keys <date>"

## Air-gapped bundle

* Tamper proof together the following objects:
    
    * [Air-gapped machine](#computer-procurement)
    
    * [AirgapOS SD card](#airgapos)

    * [Trusted keys SD card](#trusted-keys)

### Procedure

{{ #include ../../../../tamper-evidence-methods.md:vsbwf-procedure-sealing }}
